package info.aspirecn.iov.sjjh.supplier10000039.action;




import javax.servlet.http.HttpServletRequest;

import org.apache.commons.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000039.service.Supplier10000039Service;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;

/**
 * 
 * @author bzh
 *
 */
@Slf4j
@RestController
public class Supplier10000039Action {
	/**日志参数中的错误参数名*/
	private static final String LOG_ERROR_PARA = "respnoseCode";
	/**日志参数中的是否收费*/
	private static final String LOG_FEE_PARA = "isCharge";
	
	@Autowired
	private Supplier10000039Service service;
	
	@ApiOperation(value = "活体证件查询比对返照接口", notes = "")
	@PostMapping(value = "/queryUserlive.do")
    public ChannelTypeHandleResponseObject queryUserlive(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryUserlive(request, customBody, outTime);
        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes("utf-8")));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000038Action.queryUserlive.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	
	@ApiOperation(value = "eID人像证照比对编码服务接口", notes = "")
	@PostMapping(value = "/queryVoucherlive.do")
    public ChannelTypeHandleResponseObject queryVoucherlive(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.queryVoucherlive(request, customBody, outTime);
        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes("utf-8")));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000038Action.queryVoucherlive.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}
	

	@ApiOperation(value = "司机线上线下一致性验证接口", notes = "")
	@PostMapping(value = "/driverVerification.do")
    public ChannelTypeHandleResponseObject driverVerification(
    		@ApiParam(value="通道ID")@RequestHeader(name="channelId")  String channelId,
    		@ApiParam(value="超时时间,单位：毫秒",example = "10000")@RequestParam(name = "outTime", required = true) int outTime,
    		@ApiParam(value="请求参数JSON串")@RequestParam(name = "customBody", required = true) String customBody) {		
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
				.getRequest();
	
		//调用service
		ChannelTypeHandleResponseObject ret = service.driverVerification(request, customBody, outTime);
        //把接口参数、调用结果和是否收费放入访问日志中
        if(ret.getCode() != Constant.SUCCESS) {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_ERROR_CODE);
    	} else {
    		request.setAttribute(LOG_ERROR_PARA, Constant.CHANNEL_LOG_SUCCESS_CODE);
    	}
    	request.setAttribute(LOG_FEE_PARA, ret.getIsCharge());

		try {
			request.setAttribute(Constant.CHANNEL_LOG_QUERY, 
					Base64.encodeBase64String(customBody.getBytes("utf-8")));

    	} catch (Exception ex) {
    		ErrorUtils.captureException(ex);
    		log.error("Supplier10000038Action.driverVerification.Exception{}", ex);
    	}
		
		request.setAttribute(Constant.CHANNEL_TYPE_KEY,Constant.CHANNEL_TYPE_SYNC);        
        return ret;
	}

}
